==> huaweicloudsdkdli-3.1.82-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/show_quota_response_body_quotas.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowQuotaResponseBodyQuotas:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'resources': 'list[ShowQuotaPropertiesBody]'
    }

    attribute_map = {
        'project_id': 'projectId',
        'resources': 'resources'
    }

    def __init__(self, project_id=None, resources=None):
        """ShowQuotaResponseBodyQuotas

        The model defined in huaweicloud sdk

        :param project_id: 
        :type project_id: str
        :param resources: 
        :type resources: list[:class:`huaweicloudsdkdli.v1.ShowQuotaPropertiesBody`]
        """
        
        

        self._project_id = None
        self._resources = None
        self.discriminator = None

        if project_id is not None:
            self.project_id = project_id
        if resources is not None:
            self.resources = resources

    @property
    def project_id(self):
        """Gets the project_id of this ShowQuotaResponseBodyQuotas.

        :return: The project_id of this ShowQuotaResponseBodyQuotas.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ShowQuotaResponseBodyQuotas.

        :param project_id: The project_id of this ShowQuotaResponseBodyQuotas.
        :type project_id: str
        """
        self._project_id = project_id

    @property
    def resources(self):
        """Gets the resources of this ShowQuotaResponseBodyQuotas.

        :return: The resources of this ShowQuotaResponseBodyQuotas.
        :rtype: list[:class:`huaweicloudsdkdli.v1.ShowQuotaPropertiesBody`]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this ShowQuotaResponseBodyQuotas.

        :param resources: The resources of this ShowQuotaResponseBodyQuotas.
        :type resources: list[:class:`huaweicloudsdkdli.v1.ShowQuotaPropertiesBody`]
        """
        self._resources = resources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowQuotaResponseBodyQuotas):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdli-3.1.88-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/show_quota_response_body_quotas.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowQuotaResponseBodyQuotas:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'resources': 'list[QuotaInfo]'
    }

    attribute_map = {
        'project_id': 'projectId',
        'resources': 'resources'
    }

    def __init__(self, project_id=None, resources=None):
        """ShowQuotaResponseBodyQuotas

        The model defined in huaweicloud sdk

        :param project_id: 
        :type project_id: str
        :param resources: 
        :type resources: list[:class:`huaweicloudsdkdli.v1.QuotaInfo`]
        """
        
        

        self._project_id = None
        self._resources = None
        self.discriminator = None

        if project_id is not None:
            self.project_id = project_id
        if resources is not None:
            self.resources = resources

    @property
    def project_id(self):
        """Gets the project_id of this ShowQuotaResponseBodyQuotas.

        :return: The project_id of this ShowQuotaResponseBodyQuotas.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ShowQuotaResponseBodyQuotas.

        :param project_id: The project_id of this ShowQuotaResponseBodyQuotas.
        :type project_id: str
        """
        self._project_id = project_id

    @property
    def resources(self):
        """Gets the resources of this ShowQuotaResponseBodyQuotas.

        :return: The resources of this ShowQuotaResponseBodyQuotas.
        :rtype: list[:class:`huaweicloudsdkdli.v1.QuotaInfo`]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this ShowQuotaResponseBodyQuotas.

        :param resources: The resources of this ShowQuotaResponseBodyQuotas.
        :type resources: list[:class:`huaweicloudsdkdli.v1.QuotaInfo`]
        """
        self._resources = resources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowQuotaResponseBodyQuotas):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
